@@ -19,41 +19,41 @@ Params::Callbacks - Make your subroutines accept blocking callbacks
 
     use Params::Callbacks 'callbacks', 'callback';  # Or use ':all' tag
     use Data::Dumper;
-    
+
     $Data::Dumper::Indent = 0;
     $Data::Dumper::Terse  = 1;
-    
+
     sub foo
     {
-        my ( $callbacks, @params ) = &callbacks;    # If &callbacks makes the hairs on 
+        my ( $callbacks, @params ) = &callbacks;    # If &callbacks makes the hairs on
                                                     # your neck stand up, replace it with
                                                     # the cleaner alternative:
                                                     #
                                                     # Params::Callbacks->new(@_)
         return $callbacks->transform(@params);
     }
-    
+
     # No callbacks; no change to result!
     my @result_1 = foo( 0, 1, 2, 3 );
     print Dumper( [@result_1] ), "\n";  # [0,1,2,3]
-    
+
     # With callback, result is transformed before being returned!
     my @result_2 = foo( 0, 1, 2, 3, callback { 0 + 2 ** $_ } );
     print Dumper( [@result_2] ), "\n";  # [1,2,4,8]
-    
+
     # With multiple callbacks, result is transformed in multiple stages
     my @result_3 = foo( 0, 1, 2, 3, callback { 0 + 2 ** $_ } callback { 0 + 10 * $_ });
     print Dumper( [@result_3] ), "\n";  # [10,20,40,80];
-    
+
 =head1 DESCRIPTION
 
 Use this package to enable your function or method to optionally transform
 its return value, by filtering it through zero or more blocking callbacks
 passed by the caller at the end of the parameter list.
 
-At the very least, it's a bit like "map" without needing to slam your brain 
+At the very least, it's a bit like "map" without needing to slam your brain
 into reverse.
-  
+
 =cut
 
 use strict;
@@ -64,12 +64,11 @@ use Scalar::Util qw(blessed);
 use Carp qw(confess);
 use namespace::clean;
 
-our $VERSION = '2.001002';
+our $VERSION = '2.001003';
 $VERSION = eval $VERSION;
-
 our @ISA         = qw(Exporter);
-our %EXPORT_TAGS = ( all => [qw(callbacks callback)] );
-our @EXPORT_OK   = @{ $EXPORT_TAGS{all} };
+our @EXPORT_OK   = qw(callbacks callback);
+our %EXPORT_TAGS = ( all => \@EXPORT_OK, ALL => \@EXPORT_OK );
 
 =head1 METHODS
 
@@ -77,19 +76,19 @@ our @EXPORT_OK   = @{ $EXPORT_TAGS{all} };
 
 =item B<new>
 
-Accepts a list of arguments (usually C<@_>), stripping off any trailing 
-callbacks and placing them in a list blessed as a C<Params::Callbacks> 
-object. A new list is returned, beginning with the callbacks object and 
+Accepts a list of arguments (usually C<@_>), stripping off any trailing
+callbacks and placing them in a list blessed as a C<Params::Callbacks>
+object. A new list is returned, beginning with the callbacks object and
 followed by any arguments that were not callbacks:
 
-    sub my_function 
+    sub my_function
     {
         ( $callbacks, @params ) = Params::Callbacks->new(@_);
         ...
     }
 
-Callbacks in this sense are zero or more blessed code references appearing 
-at the end of an argument list. They are announced using a C<callback> 
+Callbacks in this sense are zero or more blessed code references appearing
+at the end of an argument list. They are announced using a C<callback>
 keyword:
 
     my @result = my_function(1, 2, 3, callback { 'a callback' });
@@ -106,12 +105,15 @@ standard arguments are treated as standard arguments.
 
 =cut
 
+
 sub new
 {
     my ( $class, @params ) = @_;
 
     my @callbacks;
-    while ( @params && blessed( $params[-1] ) && $params[-1]->isa('Params::Callbacks::Callback') )
+    while (    @params
+            && blessed( $params[-1] )
+            && $params[-1]->isa('Params::Callbacks::Callback') )
     {
         unshift @callbacks, pop @params;
     }
@@ -124,7 +126,7 @@ sub new
 =item B<transform>
 
 Transform a result set by passing it through all the stages of the callbacks
-pipeline. The transformation terminates if the result set is reduced to 
+pipeline. The transformation terminates if the result set is reduced to
 nothing, and an empty result set is returned.
 
 Empty or not, this method always returns a list.
@@ -133,15 +135,16 @@ Empty or not, this method always returns a list.
 
 =cut
 
+
 sub transform
 {
     my ( $callbacks, @data ) = @_;
 
-    confess 'E-PARAMS-CALLBACKS-001 Expected Params::Callbacks object reference as first argument'
+    confess
+      'E-PARAMS-CALLBACKS-001 Expected Params::Callbacks object reference as first argument'
       unless ref($callbacks) && $callbacks->isa(__PACKAGE__);
 
-    for my $callback (@$callbacks)
-    {
+    for my $callback (@$callbacks) {
         last unless @data;
         @data = map { $callback->($_) } @data;
     }
@@ -154,33 +157,31 @@ sub transform
 =item B<smart_transform>
 
 Transform a result set by passing it through all the stages of the callbacks
-pipeline. The transformation terminates if the result set is reduced to 
+pipeline. The transformation terminates if the result set is reduced to
 nothing, and an empty result set is returned.
 
 Empty or not, this method always returns a list if a list was wanted.
 
-If a scalar is required, a scalar is returned. If the result set contains a 
+If a scalar is required, a scalar is returned. If the result set contains a
 single element then the value of that element will be returned, otherwise a
-count of the number of elements is returned. 
+count of the number of elements is returned.
 
 =back
 
 =cut
 
+
 sub smart_transform
 {
     my @data = &transform;
 
-    unless (wantarray)
-    {
+    unless (wantarray) {
         my $result;
 
-        if ( @data != 1 )
-        {
+        if ( @data != 1 ) {
             $result = scalar(@data);
         }
-        else
-        {
+        else {
             $result = $data[0];
         }
 
@@ -196,20 +197,20 @@ sub smart_transform
 
 =item B<callbacks>
 
-Accepts a list of arguments (usually C<@_>), stripping off any trailing 
-callbacks and placing them in a list blessed as a C<Params::Callbacks> 
-object. A new list is returned, beginning with the callbacks object and 
+Accepts a list of arguments (usually C<@_>), stripping off any trailing
+callbacks and placing them in a list blessed as a C<Params::Callbacks>
+object. A new list is returned, beginning with the callbacks object and
 followed by any arguments that were not callbacks:
 
-    sub my_function 
+    sub my_function
     {
         ( $callbacks, @params ) = callbacks(@_);
         ( $callbacks, @params ) = &callbacks;       # Alternative invocation
         ...
     }
 
-Callbacks in this sense are zero or more blessed code references appearing 
-at the end of an argument list. They are announced using a C<callback> 
+Callbacks in this sense are zero or more blessed code references appearing
+at the end of an argument list. They are announced using a C<callback>
 keyword:
 
     my @result = my_function(1, 2, 3, callback { 'a callback' });
@@ -226,6 +227,7 @@ standard arguments are treated as standard arguments.
 
 =cut
 
+
 sub callbacks
 {
     return __PACKAGE__->new(@_);
@@ -237,19 +239,20 @@ sub callbacks
 
 A simple piece of syntactic sugar that announces a callback. The code
 reference it precedes is blessed as a C<Params::Callbacks::Callback>
-object, disambiguating it from unblessed subs that are being passed as 
+object, disambiguating it from unblessed subs that are being passed as
 standard arguments.
 
-Multiple callbacks may be chained together with or without comma 
-separators: 
+Multiple callbacks may be chained together with or without comma
+separators:
 
     callback { ... }, callback { ... }, callback { ... }    # Valid
     callback { ... }  callback { ... }  callback { ... }    # Valid, too!
-    
+
 =back
 
 =cut
 
+
 sub callback (&;@)
 {
     my ( $callback, @params ) = @_;
